==> todomod-1.7.tar.bz2: todomod/task_delete.php <==
<?php
include '../../mainfile.php';

// ⥸塼δ¤ʤϥ쥯
if (empty($xoopsModuleConfig['anonpost']) && !is_object($xoopsUser)) {
	isset($_SESSION['previous_page']) ?
	redirect_header($_SESSION['previous_page'], 0, _NOPERM):
	redirect_header("index.php", 0, _NOPERM);
	exit();
}

// ⡼ɤ_GET
isset($_GET['mode']) ? $mode=$_GET['mode'] : $mode='';

switch($mode){
case 'trashbox':
  $table='todomod_trash_task';
  $modestr='mode=trashbox&';
break;
case 'return':
  $table='todomod_trash_task';
  break;
default:
  $table='todomod_task';
}

$action = 'delete';
if (isset($_POST['task_id'])) {
	$task_id = intval($_POST['task_id']);
	$action = $_POST['op'];
} elseif (isset($_GET['task_id'])) {
	$task_id = intval($_GET['task_id']);
}

if ($task_id > 0) {

	// TodomodThread֥Ȥ
	$task_handler =& xoops_getmodulehandler('task');
	$task =& $task_handler->get($task_id, $table);
			  
	if (is_object($task)) {
		switch ($action) {

		// åɤκǧեɽ
		case 'delete':
			
		        include XOOPS_ROOT_PATH.'/header.php';

			switch($mode){
			  case 'trashbox':
			    xoops_confirm(array( 'task_id' => $task_id, 'op' => 'delete_go') ,
				  	'task_delete.php?'.$modestr.'task_id='.$task_id ,
					_MD_TODOMOD_RUSUREDELETE.'<br /><br />'.$task->getVar('task_title'), _YES);
			    break;

		       	  case 'return':
			    move_task($task,'todomod_trash_task','todomod_task',_MD_TODOMOD_RETURN_OK,_MD_TODOMOD_RETURN_NG);
			    break;

  			  default:
			    move_task($task,'todomod_task','todomod_trash_task',_MD_TODOMOD_GO_TRASH_OK,_MD_TODOMOD_GO_TRASH_NG);
			    break;
			}
			
			include XOOPS_ROOT_PATH.'/footer.php';		
		
		break;

		// åɤ
		case 'delete_go':
	
		  $task_handler->delete($task) ? 
		    $msg = _MD_TODOMOD_DELETEOK : $msg = _MD_TODOMOD_DELETENG;
		  isset($_SESSION['previous_page']) ? 
		    redirect_header($_SESSION['previous_page'], 0, $msg):redirect_header("index.php", 0, $msg);

		break;
		
		default:
		 break;
		}
	}
}

function move_task(&$task,$table_now,$table_new,$msg_OK,$msg_NG){

  $task_handler =& xoops_getmodulehandler('task');

  $task_new =& $task_handler->create();

  $task_new->setVar('task_title', $task->getVar('task_title') );
  $task_new->setVar('task_detail', $task->getVar('task_detail') );
  $task_new->setVar('task_deadline', $task->getVar('task_deadline') );
  $task_new->setVar('task_priority', $task->getVar('task_priority') );
  $task_new->setVar('task_status', $task->getVar('task_status') );
  $task_new->setVar('task_poster', $task->getVar('task_poster') );

  if (false != $task_handler->insert($task_new,true ,$table_new, $task->getVar('task_created')) 
                                                     and $task_handler->delete($task,$table_now) ) 
  $msg = $msg_OK; else $msg = $msg_NG;

  // åprevious_pageפä硢ˡ
  // ʤСindex.phpפ˥쥯Ȥ
  isset($_SESSION['previous_page']) ?
    redirect_header($_SESSION['previous_page'], 0, $msg):
    redirect_header("index.php", 0, $msg);

}


?>

==> todomod-1.9.tar.bz2: todomod/task_delete.php <==
<?php
include '../../mainfile.php';

// ⥸塼δ¤ʤϥ쥯
if (empty($xoopsModuleConfig['anonpost']) && !is_object($xoopsUser)) {
	isset($_SESSION['previous_page']) ?
	redirect_header($_SESSION['previous_page'], $xoopsModuleConfig['wait_time'], _NOPERM):
	redirect_header("index.php", $xoopsModuleConfig['wait_time'], _NOPERM);
	exit();
}

// ⡼ɤ_GET
isset($_GET['mode']) ? $mode=$_GET['mode'] : $mode='';

switch($mode){
case 'trashbox':
  $table='todomod_trash_task';
  $modestr='mode=trashbox&';
break;
case 'return':
  $table='todomod_trash_task';
  break;
default:
  $table='todomod_task';
}

$action = 'delete';
if (isset($_POST['task_id'])) {
	$task_id = intval($_POST['task_id']);
	$action = $_POST['op'];
} elseif (isset($_GET['task_id'])) {
	$task_id = intval($_GET['task_id']);
}

if ($task_id > 0) {

	// TodomodThread֥Ȥ
	$task_handler =& xoops_getmodulehandler('task');
	$task =& $task_handler->get($task_id, $table);
			  
	if (is_object($task)) {
		switch ($action) {

		// åɤκǧեɽ
		case 'delete':
			
		        include XOOPS_ROOT_PATH.'/header.php';

			switch($mode){
			  case 'trashbox':
			    xoops_confirm(array( 'task_id' => $task_id, 'op' => 'delete_go') ,
				  	'task_delete.php?'.$modestr.'task_id='.$task_id ,
					_MD_TODOMOD_RUSUREDELETE.'<br /><br />'.$task->getVar('task_title'), _YES);
			    break;

		       	  case 'return':
			    move_task($task,'todomod_trash_task','todomod_task',_MD_TODOMOD_RETURN_OK,_MD_TODOMOD_RETURN_NG);
			    break;

  			  default:
			    move_task($task,'todomod_task','todomod_trash_task',_MD_TODOMOD_GO_TRASH_OK,_MD_TODOMOD_GO_TRASH_NG);
			    break;
			}
			
			include XOOPS_ROOT_PATH.'/footer.php';		
		
		break;

		// åɤ
		case 'delete_go':
	
		  $task_handler->delete($task) ? 
		    $msg = _MD_TODOMOD_DELETEOK : $msg = _MD_TODOMOD_DELETENG;
		  isset($_SESSION['previous_page']) ? 
		    redirect_header($_SESSION['previous_page'], $xoopsModuleConfig['wait_time'], $msg):redirect_header("index.php", $xoopsModuleConfig['wait_time'], $msg);
		break;
		
		default:
		 break;
		}
	}
}

function move_task(&$task,$table_now,$table_new,$msg_OK,$msg_NG){

  $task_handler =& xoops_getmodulehandler('task');

  $task_new =& $task_handler->create();

  $task_new->setVar('task_title', $task->getVar('task_title') );
  $task_new->setVar('task_detail', $task->getVar('task_detail') );
  $task_new->setVar('task_deadline', $task->getVar('task_deadline') );
  $task_new->setVar('task_priority', $task->getVar('task_priority') );
  $task_new->setVar('task_status', $task->getVar('task_status') );
  $task_new->setVar('task_poster', $task->getVar('task_poster') );

  if (false != $task_handler->insert($task_new,true ,$table_new, $task->getVar('task_created')) 
                                                     and $task_handler->delete($task,$table_now) ) 
  $msg = $msg_OK; else $msg = $msg_NG;
  
  global $xoopsModuleConfig;
  
  // åprevious_pageפä硢ˡ
  // ʤСindex.phpפ˥쥯Ȥ
  isset($_SESSION['previous_page']) ?
    redirect_header($_SESSION['previous_page'], $xoopsModuleConfig['wait_time'], $msg):
    redirect_header("index.php", $xoopsModuleConfig['wait_time'], $msg);

}


?>
